[xoops-cvslog 2164] CVS update: xoops2jp/html/modules/base/admin/actions

Zurück zum Archiv-Index

Minahito minah****@users*****
2006年 2月 3日 (金) 17:33:25 JST


Index: xoops2jp/html/modules/base/admin/actions/InstallListAction.class.php
diff -u xoops2jp/html/modules/base/admin/actions/InstallListAction.class.php:1.1.2.1 xoops2jp/html/modules/base/admin/actions/InstallListAction.class.php:1.1.2.2
--- xoops2jp/html/modules/base/admin/actions/InstallListAction.class.php:1.1.2.1	Thu Feb  2 21:22:44 2006
+++ xoops2jp/html/modules/base/admin/actions/InstallListAction.class.php	Fri Feb  3 17:33:25 2006
@@ -1,26 +1,16 @@
 <?php
 
-//
-// TODO We should to delete the original handler style.
-//
-require_once XOOPS_BASE_PATH."/admin/class/DeactiveModuleHandler.class.php";
-
 /**
  * List up modules that are not installed yet.
  */
 class Legacy_InstallListAction extends Legacy_Action
 {
 	var $mModuleObjects = null;
 	
-	function prepare(&$controller, &$xoopsUser)
-	{
-	}
-	
 	function getDefaultView(&$controller, &$xoopsUser)
 	{
-		$db =& $controller->getDB();
-		$handler = new Legacy_DeactiveModuleHandler($db);
-		
+		$handler =& xoops_getmodulehandler('non_installation_module');
+
 		$this->mModuleObjects =& $handler->getObjects();
 		
 		return LEGACY_FRAME_VIEW_INDEX;
@@ -1,26 +1,16 @@
 /**
- * List up modules that are not installed yet.
+ * List up non-installation modules.
  */
 class Legacy_InstallListAction extends Legacy_Action


xoops-cvslog メーリングリストの案内
Zurück zum Archiv-Index